===============
Flask-And-Redis
===============

.. image:: https://travis-ci.org/playpauseandstop/Flask-And-Redis.png?branch=master&style=flat
    :target: https://travis-ci.org/playpauseandstop/Flask-And-Redis
    :alt: Travis CI

.. image:: https://coveralls.io/repos/github/playpauseandstop/Flask-And-Redis/badge.svg?branch=master
    :target: https://coveralls.io/github/playpauseandstop/Flask-And-Redis?branch=master
    :alt: Coverage

.. image:: https://img.shields.io/pypi/v/Flask-And-Redis.svg
    :target: https://pypi.python.org/pypi/Flask-And-Redis/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/pyversions/Flask-And-Redis.svg
    :target: https://pypi.python.org/pypi/Flask-And-Redis/
    :alt: Python versions

.. image:: https://img.shields.io/pypi/l/Flask-And-Redis.svg
    :target: https://github.com/playpauseandstop/Flask-And-Redis/blob/master/LICENSE
    :alt: BSD License

.. image:: https://readthedocs.org/projects/flask-and-redis/badge/?version=latest
    :target: http://flask-and-redis.readthedocs.org/en/latest/
    :alt: Documentation

Flask-And-Redis provides simple as dead support of `Redis <http://redis.io>`_
database for `Flask <http://flask.pocoo.org/>`_ applications. Extension built
around beautiful `redis-py <https://github.com/andymccurdy/redis-py>`_ library
by Andy McCurdy.

* Works on Python 2.7, 3.4+
* BSD licensed
* Latest documentation `on Read the Docs
  <http://flask-and-redis.readthedocs.org>`_
* Source, issues and pull requests `on GitHub
  <https://github.com/playpauseandstop/Flask-And-Redis>`_
* Install with ``pip install Flask-And-Redis``

.. note:: ``Flask-And-Redis`` named as is, cause ``Flask-Redis`` name already
   `taken <http://pypi.python.org/pypi/Flask-Redis>`_, but that library didn't
   match my needs.
